chunkKeyFor method

String chunkKeyFor(
  1. String key,
  2. int generation,
  3. int index
)

The backing-record key of chunk index in generation of key. For subclasses whose materialize reads chunk records directly — pair with manifestFor to get the current generation.

Implementation

String chunkKeyFor(String key, int generation, int index) =>
    '$key$generationPrefix$generation$chunkPrefix$index';