readRange method

  1. @override
Future<Uint8List> readRange(
  1. String key, {
  2. required int start,
  3. required int length,
})
override

Read a byte range.

Returns bytes starting at start with the given length. For encrypted files, only the overlapping chunks are decrypted; for chunked files, only the overlapping chunk records are read.

Implementation

@override
Future<Uint8List> readRange(
  String key, {
  required int start,
  required int length,
}) => throw UnsupportedError('stub');