readRange abstract method

Future<Uint8List> readRange(
  1. String key, {
  2. required int start,
  3. required int length,
})

Read a byte range.

Returns bytes starting at start with the given length. For encrypted files, only the overlapping chunks are decrypted; for chunked files, only the overlapping chunk records are read.

Implementation

Future<Uint8List> readRange(
  String key, {
  required int start,
  required int length,
});