encryptionKey property

Object? encryptionKey
final

Explicit per-call encryption key.

When null (the default), the EncryptedBackend looks the key up via its EncryptionKeyResolver. Only meaningful when this write will be encrypted (either encrypt is true or the default resolves to encrypt).

Implementation

final Object? encryptionKey;