EncryptionKeyMissingError class

Encryption was requested but no key could be resolved.

Inheritance

Constructors

EncryptionKeyMissingError(String key)
key is the object whose encryption key failed to resolve.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
The storage key involved in the error (null for non-key-specific errors).
finalinherited
message String
Human-readable error description.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited